==> tubebrowser-0.0.1.tar.gz: tubebrowser-0.0.1/translations/tubebrowser_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ja_JP">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/mainwindow.cc" line="22"/>
        <location filename="../src/mainwindow.cc" line="161"/>
        <source>TubeBrowser</source>
        <translation>TubeBrowser</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cc" line="70"/>
        <source>&amp;Open</source>
        <translation>開く(&amp;O)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cc" line="74"/>
        <location filename="../src/mainwindow.cc" line="198"/>
        <source>Open URL...</source>
        <translation>URLを開く...</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cc" line="75"/>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cc" line="78"/>
        <source>E&amp;xit</source>
        <translation>終了(&amp;X)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cc" line="81"/>
        <source>Playlist</source>
        <translation>プレイリスト</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cc" line="87"/>
        <source>Seek Bar</source>
        <translation>シークバー</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cc" line="93"/>
        <source>On Top</source>
        <translation>最前面表示</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cc" line="95"/>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cc" line="99"/>
        <source>P&amp;lay</source>
        <translation>再生(&amp;P)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cc" line="102"/>
        <source>&amp;Stop</source>
        <translation>停止(&amp;S)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cc" line="105"/>
        <source>Pause</source>
        <translation>一時停止</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cc" line="108"/>
        <source>Home Page</source>
        <translation>ホームページ</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cc" line="111"/>
        <source>&amp;About</source>
        <translation>情報(&amp;A)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cc" line="122"/>
        <source>Clear All</source>
        <translation>すべてクリア</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cc" line="127"/>
        <source>&amp;File</source>
        <translation>ファイル(&amp;F)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cc" line="131"/>
        <source>Recent Files</source>
        <translation>最近見たファイル</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cc" line="142"/>
        <source>&amp;View</source>
        <translation>表示(&amp;V)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cc" line="149"/>
        <source>&amp;Play</source>
        <translation>再生(&amp;P)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cc" line="154"/>
        <source>&amp;Help</source>
        <translation>ヘルプ(&amp;H)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cc" line="161"/>
        <source>%1 - %2</source>
        <translation>%1 - %2</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cc" line="166"/>
        <source>About TubeBrowser</source>
        <translation>TubeBrowserについて</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cc" line="174"/>
        <source>Choose a file to open</source>
        <translation>開くファイルを選択してください</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cc" line="176"/>
        <source>FLV files (*.flv);;All files (*.*)</source>
        <translation>FLVファイル(*.flv);;すべてのファイル(*.*)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cc" line="199"/>
        <source>Enter the address of the file you would like to open:</source>
        <translation>開きたいファイルのアドレスを入力してください:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cc" line="239"/>
        <source>&amp;%1 %2</source>
        <translation>&amp;%1 - %2</translation>
    </message>
</context>
<context>
    <name>Player</name>
    <message>
        <location filename="../src/player.cc" line="194"/>
        <source>Playing</source>
        <translation>再生中</translation>
    </message>
    <message>
        <location filename="../src/player.cc" line="79"/>
        <location filename="../src/player.cc" line="206"/>
        <source>Stopped</source>
        <translation>停止</translation>
    </message>
    <message>
        <location filename="../src/player.cc" line="220"/>
        <source>Paused</source>
        <translation>一時停止</translation>
    </message>
    <message>
        <location filename="../src/player.cc" line="276"/>
        <source>Play</source>
        <translation>再生</translation>
    </message>
    <message>
        <location filename="../src/player.cc" line="280"/>
        <source>Pause</source>
        <translation>一時停止</translation>
    </message>
    <message>
        <location filename="../src/player.cc" line="284"/>
        <source>Stop</source>
        <translation>停止</translation>
    </message>
    <message>
        <location filename="../src/player.cc" line="294"/>
        <source>Volume</source>
        <translation>音量</translation>
    </message>
</context>
<context>
    <name>Playlist</name>
    <message>
        <location filename="../src/playlist.cc" line="20"/>
        <source>Playlist</source>
        <translation>プレイリスト</translation>
    </message>
</context>
</TS>

==> tubebrowser-0.0.2.tar.gz: tubebrowser-0.0.2/translations/tubebrowser_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ja_JP">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/mainwindow.cc" line="25"/>
        <location filename="../src/mainwindow.cc" line="179"/>
        <source>TubeBrowser</source>
        <translation>TubeBrowser</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cc" line="77"/>
        <source>&amp;Open</source>
        <translation>開く(&amp;O)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cc" line="81"/>
        <location filename="../src/mainwindow.cc" line="218"/>
        <source>Open URL...</source>
        <translation>URLを開く...</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cc" line="82"/>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cc" line="85"/>
        <source>Copy Current URL</source>
        <translation>現在のURLをコピー</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cc" line="88"/>
        <source>Download Current Video</source>
        <translation>現在の動画をダウンロード</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cc" line="92"/>
        <source>E&amp;xit</source>
        <translation>終了(&amp;X)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cc" line="95"/>
        <source>Playlist</source>
        <translation>プレイリスト</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cc" line="101"/>
        <source>Seek Bar</source>
        <translation>シークバー</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cc" line="107"/>
        <source>On Top</source>
        <translation>最前面表示</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cc" line="109"/>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cc" line="113"/>
        <source>P&amp;lay</source>
        <translation>再生(&amp;P)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cc" line="116"/>
        <source>&amp;Stop</source>
        <translation>停止(&amp;S)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cc" line="119"/>
        <source>Pause</source>
        <translation>一時停止</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cc" line="122"/>
        <source>Home Page</source>
        <translation>ホームページ</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cc" line="125"/>
        <source>&amp;About</source>
        <translation>情報(&amp;A)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cc" line="136"/>
        <source>Clear All</source>
        <translation>すべてクリア</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cc" line="141"/>
        <source>&amp;File</source>
        <translation>ファイル(&amp;F)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cc" line="145"/>
        <source>Recent Files</source>
        <translation>最近見たファイル</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cc" line="160"/>
        <source>&amp;View</source>
        <translation>表示(&amp;V)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cc" line="167"/>
        <source>&amp;Play</source>
        <translation>再生(&amp;P)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cc" line="172"/>
        <source>&amp;Help</source>
        <translation>ヘルプ(&amp;H)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cc" line="179"/>
        <source>%1 - %2</source>
        <translation>%1 - %2</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cc" line="184"/>
        <source>About TubeBrowser</source>
        <translation>TubeBrowserについて</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cc" line="193"/>
        <source>Choose a file to open</source>
        <translation>開くファイルを選択してください</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cc" line="195"/>
        <source>FLV files (*.flv);;All files (*.*)</source>
        <translation>FLVファイル(*.flv);;すべてのファイル(*.*)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cc" line="219"/>
        <source>Enter the address of the file you would like to open:</source>
        <translation>開きたいファイルのアドレスを入力してください:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cc" line="267"/>
        <source>&amp;%1 %2</source>
        <translation>&amp;%1 - %2</translation>
    </message>
</context>
<context>
    <name>Player</name>
    <message>
        <location filename="../src/player.cc" line="194"/>
        <source>Playing</source>
        <translation>再生中</translation>
    </message>
    <message>
        <location filename="../src/player.cc" line="79"/>
        <location filename="../src/player.cc" line="206"/>
        <source>Stopped</source>
        <translation>停止</translation>
    </message>
    <message>
        <location filename="../src/player.cc" line="220"/>
        <source>Paused</source>
        <translation>一時停止</translation>
    </message>
    <message>
        <location filename="../src/player.cc" line="276"/>
        <source>Play</source>
        <translation>再生</translation>
    </message>
    <message>
        <location filename="../src/player.cc" line="280"/>
        <source>Pause</source>
        <translation>一時停止</translation>
    </message>
    <message>
        <location filename="../src/player.cc" line="284"/>
        <source>Stop</source>
        <translation>停止</translation>
    </message>
    <message>
        <location filename="../src/player.cc" line="294"/>
        <source>Volume</source>
        <translation>音量</translation>
    </message>
</context>
<context>
    <name>Playlist</name>
    <message>
        <location filename="../src/playlist.cc" line="14"/>
        <source>Load</source>
        <translation>読み込み</translation>
    </message>
    <message>
        <location filename="../src/playlist.cc" line="17"/>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <location filename="../src/playlist.cc" line="20"/>
        <source>Clear All</source>
        <translation>すべてクリア</translation>
    </message>
    <message>
        <location filename="../src/playlist.cc" line="23"/>
        <source>Delete</source>
        <translation>削除</translation>
    </message>
    <message>
        <location filename="../src/playlist.cc" line="42"/>
        <source>Playlist</source>
        <translation>プレイリスト</translation>
    </message>
    <message>
        <location filename="../src/playlist.cc" line="113"/>
        <source>Choose a file to open</source>
        <translation>開くファイルを選択してください</translation>
    </message>
    <message>
        <location filename="../src/playlist.cc" line="115"/>
        <location filename="../src/playlist.cc" line="145"/>
        <source>Playlist files (*.txt);;All files (*.*)</source>
        <translation>プレイリストファイル(*.txt);;すべてのファイル(*.*)</translation>
    </message>
    <message>
        <location filename="../src/playlist.cc" line="143"/>
        <source>Save playlist as ...</source>
        <translation>プレイリストを保存...</translation>
    </message>
</context>
</TS>
